Skip to contents

In POS, collapse upos ADP, if the previous and the next pos are NOUN or PROPN. It is used in the pipeline to extract proper names like "United States of America"

Usage

collapse_adp(pos_df)

Arguments

pos_df

the POS dataframe generated by spacy_parse

Examples