from a list of filtered text (from the function filter_by_query), tags the POS/ parse with spacyr. It also renumber the doc_id and sentence_id. It runs spacyr::entity_extract() or spacyr::entity_consolidate() in background, but also runs on lists with empty elements, and can returns a single dataframe (if `bind = TRUE`) renaming doc_id and sentence_id,
Examples
txt_wiki |>
filter_by_query("Police") |>
parsePOS()
#> doc_id sentence_id entity entity_type
#> 1 text1 1 Pennsylvania GPE
#> 2 text1 1 New_Jersey GPE
#> 3 text2 1 Ted_Kaczynski_'s PERSON
#> 4 text2 1 Industrial_Society_and_Its_Future ORG
#> 5 text1 2 the_George_Washington_Bridge_Bus_Station ORG
#> 6 text1 2 Upper_Manhattan LOC
#> 7 text1 1 Central_Park LOC
#> 8 text1 1 New_York_City GPE
#> 9 text1 2 Mangione ORG
#> 10 text1 2 the_San_Francisco_Police_Department ORG
#> 11 text1 2 Mangione ORG
#> 12 text1 2 San_Francisco GPE
#> 13 text1 1 Altoona GPE
#> 14 text1 1 Pennsylvania GPE
#> 15 text1 1 Mangione ORG
#> 16 text1 1 McDonald ORG
#> 17 text2 1 NYPD ORG
#> 18 text3 2 New_Jersey GPE
#> 19 text3 2 Manhattan GPE
#> 20 text4 1 American NORP
#> 21 text1 1 Mangione ORG
#> 22 text2 1 New_York GPE
#> 23 text2 1 Joseph_Kenny PERSON
#> 24 text1 1 Mangione ORG
#> 25 text1 1 Ted_Kaczynski_'s PERSON
#> 26 text1 1 Industrial_Society_and_Its_Future ORG
txt_wiki |>
filter_by_query("Police") |>
parsePOS(only_entities = FALSE)
#> doc_id sentence_id token_id token
#> 1 4 1 1 11
#> 2 4 1 2 ]
#> 3 4 1 3 Mangione
#> 4 4 1 4 was
#> 5 4 1 5 held
#> 6 4 1 6 without
#> 7 4 1 7 bail
#> 8 4 1 8 in
#> 9 4 1 9 Pennsylvania
#> 10 4 1 10 on
#> 11 4 1 11 charges
#> 12 4 1 12 of
#> 13 4 1 13 possession
#> 14 4 1 14 of
#> 15 4 1 15 an
#> 16 4 1 16 unlicensed
#> 17 4 1 17 firearm
#> 18 4 1 18 ,
#> 19 4 1 19 forgery
#> 20 4 1 20 ,
#> 21 4 1 21 and
#> 22 4 1 22 providing
#> 23 4 1 23 false
#> 24 4 1 24 New_Jersey
#> 25 4 1 25 -
#> 26 4 1 26 resident
#> 27 4 1 27 identification
#> 28 4 1 28 to
#> 29 4 1 29 police
#> 30 4 1 30 .
#> 31 4 1 1 [
#> 32 4 2 1 12
#> 33 4 2 2 ]
#> 34 4 2 3 Police
#> 35 4 2 4 believe
#> 36 4 2 5 that
#> 37 4 2 6 he
#> 38 4 2 7 was
#> 39 4 2 8 inspired
#> 40 4 2 9 by
#> 41 4 2 10 Ted_Kaczynski_'s
#> 42 4 2 11 essay
#> 43 4 2 12 Industrial_Society_and_Its_Future
#> 44 4 2 13 (
#> 45 4 2 14 1995
#> 46 4 2 15 )
#> 47 4 2 16 ,
#> 48 4 2 17 and
#> 49 4 2 18 motivated
#> 50 4 2 19 by
#> 51 4 2 20 his
#> 52 4 2 21 personal
#> 53 4 2 22 views
#> 54 4 2 23 on
#> 55 4 2 24 health
#> 56 4 2 25 insurance
#> 57 4 2 26 .
#> 58 4 2 1 [
#> 59 12 1 1 39
#> 60 12 1 2 ]
#> 61 12 1 1 According
#> 62 12 1 2 to
#> 63 12 1 3 the
#> 64 12 1 4 police
#> 65 12 1 5 ,
#> 66 12 1 6 he
#> 67 12 1 7 then
#> 68 12 1 8 left
#> 69 12 1 9 the
#> 70 12 1 10 city
#> 71 12 1 11 from
#> 72 12 1 12 the_George_Washington_Bridge_Bus_Station
#> 73 12 1 13 farther
#> 74 12 1 14 uptown
#> 75 12 1 15 in
#> 76 12 1 16 Upper_Manhattan
#> 77 12 1 17 .
#> 78 12 1 1 [
#> 79 13 1 1 49
#> 80 13 1 2 ]
#> 81 13 1 1 Accordingly
#> 82 13 1 2 ,
#> 83 13 1 3 police
#> 84 13 1 4 stated
#> 85 13 1 5 they
#> 86 13 1 6 are
#> 87 13 1 7 investigating
#> 88 13 1 8 whether
#> 89 13 1 9 the
#> 90 13 1 10 words
#> 91 13 1 11 suggest
#> 92 13 1 12 the
#> 93 13 1 13 killer
#> 94 13 1 14 's
#> 95 13 1 15 motive
#> 96 13 1 16 .
#> 97 13 1 1 [
#> 98 14 1 1 50
#> 99 14 1 2 ]
#> 100 14 1 3 Police
#> 101 14 1 4 said
#> 102 14 1 5 they
#> 103 14 1 6 believed
#> 104 14 1 7 they
#> 105 14 1 8 found
#> 106 14 1 9 the
#> 107 14 1 10 shooter
#> 108 14 1 11 's
#> 109 14 1 12 backpack
#> 110 14 1 13 in
#> 111 14 1 14 Central_Park
#> 112 14 1 15 on
#> 113 14 1 16 December_6_,_2024
#> 114 14 1 17 .
#> 115 14 1 1 [
#> 116 15 1 1 The
#> 117 15 1 2 New_York_City
#> 118 15 1 3 Police
#> 119 15 1 4 Department
#> 120 15 1 5 offered
#> 121 15 1 6 a
#> 122 15 1 7 reward
#> 123 15 1 8 up_to_$_10,000
#> 124 15 1 9 for
#> 125 15 1 10 information
#> 126 15 1 11 about
#> 127 15 1 12 the
#> 128 15 1 13 shooter
#> 129 15 1 14 on
#> 130 15 1 15 December_4_,_2024
#> 131 15 1 16 .
#> 132 15 1 1 [
#> 133 16 1 1 The
#> 134 16 1 2 shooter
#> 135 16 1 3 was
#> 136 16 1 4 described
#> 137 16 1 5 by
#> 138 16 1 6 police
#> 139 16 1 7 as
#> 140 16 1 8 a
#> 141 16 1 9 white
#> 142 16 1 10 man
#> 143 16 1 11 ,
#> 144 16 1 12 approximately_6
#> 145 16 1 13 ft
#> 146 16 1 14 1
#> 147 16 1 15 in
#> 148 16 1 16 (
#> 149 16 1 17 185_cm
#> 150 16 1 18 )
#> 151 16 1 19 tall
#> 152 16 1 20 ,
#> 153 16 1 21 wearing
#> 154 16 1 22 a
#> 155 16 1 23 light
#> 156 16 1 24 brown
#> 157 16 1 25 or
#> 158 16 1 26 cream
#> 159 16 1 27 -
#> 160 16 1 28 colored
#> 161 16 1 29 hooded
#> 162 16 1 30 jacket
#> 163 16 1 31 ,
#> 164 16 1 32 dark
#> 165 16 1 33 pants
#> 166 16 1 34 ,
#> 167 16 1 35 and
#> 168 16 1 36 black
#> 169 16 1 37 sneakers
#> 170 16 1 38 with
#> 171 16 1 39 white
#> 172 16 1 40 soles
#> 173 16 1 41 .
#> 174 16 2 1 31][39][57][58
#> 175 16 2 2 ]
#> 176 16 2 3 Police
#> 177 16 2 4 said
#> 178 16 2 5 the
#> 179 16 2 6 suspect
#> 180 16 2 7 appeared
#> 181 16 2 8 to
#> 182 16 2 9 be
#> 183 16 2 10 proficient
#> 184 16 2 11 in
#> 185 16 2 12 the
#> 186 16 2 13 use
#> 187 16 2 14 of
#> 188 16 2 15 firearms[30
#> 189 16 2 16 ]
#> 190 16 2 17 and
#> 191 16 2 18 was
#> 192 16 2 19 described
#> 193 16 2 20 as
#> 194 16 2 21 being
#> 195 16 2 22 "
#> 196 16 2 23 extremely
#> 197 16 2 24 camera
#> 198 16 2 25 savvy
#> 199 16 2 26 .
#> 200 16 2 27 "
#> 201 16 2 1 [
#> 202 18 1 1 69
#> 203 18 1 2 ]
#> 204 18 1 1 Mangione
#> 205 18 1 2 's
#> 206 18 1 3 mother
#> 207 18 1 4 contacted
#> 208 18 1 5 the_San_Francisco_Police_Department
#> 209 18 1 6 ,
#> 210 18 1 7 as
#> 211 18 1 8 she
#> 212 18 1 9 believed
#> 213 18 1 10 that
#> 214 18 1 11 Mangione
#> 215 18 1 12 lived
#> 216 18 1 13 in
#> 217 18 1 14 San_Francisco
#> 218 18 1 15 and
#> 219 18 1 16 had
#> 220 18 1 17 a
#> 221 18 1 18 job
#> 222 18 1 19 in
#> 223 18 1 20 the
#> 224 18 1 21 area
#> 225 18 1 22 .
#> 226 18 1 1 [
#> 227 19 1 1 Local
#> 228 19 1 2 police
#> 229 19 1 3 in
#> 230 19 1 4 Altoona
#> 231 19 1 5 ,
#> 232 19 1 6 Pennsylvania
#> 233 19 1 7 ,
#> 234 19 1 8 arrested
#> 235 19 1 9 Mangione
#> 236 19 1 10 on
#> 237 19 1 11 December_9_,_2024
#> 238 19 1 12 ,
#> 239 19 1 13 at
#> 240 19 1 14 a
#> 241 19 1 15 McDonald
#> 242 19 1 16 's
#> 243 19 1 17 restaurant
#> 244 19 1 18 in
#> 245 19 1 19 the
#> 246 19 1 20 city
#> 247 19 1 21 .
#> 248 19 2 1 An
#> 249 19 2 2 employee
#> 250 19 2 3 there
#> 251 19 2 4 called
#> 252 19 2 5 the
#> 253 19 2 6 police
#> 254 19 2 7 to
#> 255 19 2 8 say
#> 256 19 2 9 that
#> 257 19 2 10 a
#> 258 19 2 11 customer
#> 259 19 2 12 recognized
#> 260 19 2 13 the
#> 261 19 2 14 suspect
#> 262 19 2 15 from
#> 263 19 2 16 images
#> 264 19 2 17 released
#> 265 19 2 18 by
#> 266 19 2 19 the
#> 267 19 2 20 NYPD
#> 268 19 2 21 .
#> 269 19 2 1 [
#> 270 19 3 1 63
#> 271 19 3 2 ]
#> 272 19 3 1 In
#> 273 19 3 2 his
#> 274 19 3 3 bag
#> 275 19 3 4 they
#> 276 19 3 5 found
#> 277 19 3 6 a
#> 278 19 3 7 3D
#> 279 19 3 8 -
#> 280 19 3 9 printed
#> 281 19 3 10 gun
#> 282 19 3 11 and
#> 283 19 3 12 a
#> 284 19 3 13 3D
#> 285 19 3 14 -
#> 286 19 3 15 printed
#> 287 19 3 16 suppressor
#> 288 19 3 17 ,
#> 289 19 3 18 which
#> 290 19 3 19 the
#> 291 19 3 20 police
#> 292 19 3 21 claim
#> 293 19 3 22 are
#> 294 19 3 23 consistent
#> 295 19 3 24 with
#> 296 19 3 25 the
#> 297 19 3 26 weapon
#> 298 19 3 27 used
#> 299 19 3 28 in
#> 300 19 3 29 the
#> 301 19 3 30 shooting
#> 302 19 3 31 ,
#> 303 19 3 32 and
#> 304 19 3 33 a
#> 305 19 3 34 falsified
#> 306 19 3 35 New_Jersey
#> 307 19 3 36 driver
#> 308 19 3 37 's
#> 309 19 3 38 license
#> 310 19 3 39 with
#> 311 19 3 40 the
#> 312 19 3 41 same
#> 313 19 3 42 name
#> 314 19 3 43 as
#> 315 19 3 44 the
#> 316 19 3 45 one
#> 317 19 3 46 used
#> 318 19 3 47 by
#> 319 19 3 48 the
#> 320 19 3 49 alleged
#> 321 19 3 50 shooter
#> 322 19 3 51 to
#> 323 19 3 52 check
#> 324 19 3 53 into
#> 325 19 3 54 the
#> 326 19 3 55 Manhattan
#> 327 19 3 56 hostel
#> 328 19 3 57 .
#> 329 19 3 1 [
#> 330 19 4 1 8][73][3][74
#> 331 19 4 2 ]
#> 332 19 4 3
#> 333 19 4 4 The
#> 334 19 4 5 police
#> 335 19 4 6 also
#> 336 19 4 7 said
#> 337 19 4 8 that
#> 338 19 4 9 when
#> 339 19 4 10 they
#> 340 19 4 11 arrested
#> 341 19 4 12 Mangione
#> 342 19 4 13 ,
#> 343 19 4 14 they
#> 344 19 4 15 found
#> 345 19 4 16 a
#> 346 19 4 17 three_-_page,[74_]
#> 347 19 4 18 262
#> 348 19 4 19 -
#> 349 19 4 20 word
#> 350 19 4 21 handwritten
#> 351 19 4 22 document
#> 352 19 4 23 about
#> 353 19 4 24 the
#> 354 19 4 25 American
#> 355 19 4 26 healthcare
#> 356 19 4 27 system
#> 357 19 4 28 ,
#> 358 19 4 29 which
#> 359 19 4 30 they
#> 360 19 4 31 characterized
#> 361 19 4 32 as
#> 362 19 4 33 a
#> 363 19 4 34 manifesto
#> 364 19 4 35 .
#> 365 19 4 1 [
#> 366 23 1 1 85
#> 367 23 1 2 ]
#> 368 23 1 3 Police
#> 369 23 1 4 believe
#> 370 23 1 5 the
#> 371 23 1 6 motive
#> 372 23 1 7 was
#> 373 23 1 8 related
#> 374 23 1 9 to
#> 375 23 1 10 an
#> 376 23 1 11 injury
#> 377 23 1 12 that
#> 378 23 1 13 Mangione
#> 379 23 1 14 had
#> 380 23 1 15 suffered
#> 381 23 1 16 that
#> 382 23 1 17 caused
#> 383 23 1 18 him
#> 384 23 1 19 to
#> 385 23 1 20 visit
#> 386 23 1 21 the
#> 387 23 1 22 emergency
#> 388 23 1 23 room
#> 389 23 1 24 in
#> 390 23 1 25 July_2023
#> 391 23 1 26 .
#> 392 23 2 1 New_York
#> 393 23 2 2 Police
#> 394 23 2 3 Chief
#> 395 23 2 4 of
#> 396 23 2 5 Detectives
#> 397 23 2 6 Joseph_Kenny
#> 398 23 2 7 believes
#> 399 23 2 8 Mangione
#> 400 23 2 9 may
#> 401 23 2 10 have
#> 402 23 2 11 targeted
#> 403 23 2 12 them
#> 404 23 2 13 because
#> 405 23 2 14 of
#> 406 23 2 15 the
#> 407 23 2 16 company
#> 408 23 2 17 's
#> 409 23 2 18 size
#> 410 23 2 19 .
#> 411 23 2 1 [
#> 412 24 1 1 Police
#> 413 24 1 2 believe
#> 414 24 1 3 that
#> 415 24 1 4 Mangione
#> 416 24 1 5 was
#> 417 24 1 6 inspired
#> 418 24 1 7 by
#> 419 24 1 8 Ted_Kaczynski_'s
#> 420 24 1 9 Industrial_Society_and_Its_Future
#> 421 24 1 10 .
#> 422 24 1 1 [
#> lemma pos entity_type
#> 1 11 ENTITY CARDINAL
#> 2 ] PUNCT
#> 3 mangione NOUN
#> 4 be AUX
#> 5 hold VERB
#> 6 without ADP
#> 7 bail NOUN
#> 8 in ADP
#> 9 Pennsylvania ENTITY GPE
#> 10 on ADP
#> 11 charge NOUN
#> 12 of ADP
#> 13 possession NOUN
#> 14 of ADP
#> 15 an DET
#> 16 unlicensed ADJ
#> 17 firearm NOUN
#> 18 , PUNCT
#> 19 forgery NOUN
#> 20 , PUNCT
#> 21 and CCONJ
#> 22 provide VERB
#> 23 false ADJ
#> 24 New_Jersey ENTITY GPE
#> 25 - PUNCT
#> 26 resident NOUN
#> 27 identification NOUN
#> 28 to ADP
#> 29 police NOUN
#> 30 . PUNCT
#> 31 [ X
#> 32 12 ENTITY CARDINAL
#> 33 ] PUNCT
#> 34 Police NOUN
#> 35 believe VERB
#> 36 that SCONJ
#> 37 he PRON
#> 38 be AUX
#> 39 inspire VERB
#> 40 by ADP
#> 41 Ted_Kaczynski_'s ENTITY PERSON
#> 42 essay ADJ
#> 43 Industrial_Society_and_its_future ENTITY ORG
#> 44 ( PUNCT
#> 45 1995 ENTITY DATE
#> 46 ) PUNCT
#> 47 , PUNCT
#> 48 and CCONJ
#> 49 motivate VERB
#> 50 by ADP
#> 51 his PRON
#> 52 personal ADJ
#> 53 view NOUN
#> 54 on ADP
#> 55 health NOUN
#> 56 insurance NOUN
#> 57 . PUNCT
#> 58 [ X
#> 59 39 ENTITY CARDINAL
#> 60 ] PUNCT
#> 61 accord VERB
#> 62 to ADP
#> 63 the DET
#> 64 police NOUN
#> 65 , PUNCT
#> 66 he PRON
#> 67 then ADV
#> 68 leave VERB
#> 69 the DET
#> 70 city NOUN
#> 71 from ADP
#> 72 the_George_Washington_Bridge_Bus_Station ENTITY ORG
#> 73 far ADV
#> 74 uptown VERB
#> 75 in ADP
#> 76 Upper_Manhattan ENTITY LOC
#> 77 . PUNCT
#> 78 [ X
#> 79 49 ENTITY CARDINAL
#> 80 ] PUNCT
#> 81 accordingly ADV
#> 82 , PUNCT
#> 83 police NOUN
#> 84 state VERB
#> 85 they PRON
#> 86 be AUX
#> 87 investigate VERB
#> 88 whether SCONJ
#> 89 the DET
#> 90 word NOUN
#> 91 suggest VERB
#> 92 the DET
#> 93 killer NOUN
#> 94 's PART
#> 95 motive NOUN
#> 96 . PUNCT
#> 97 [ X
#> 98 50 ENTITY CARDINAL
#> 99 ] PUNCT
#> 100 Police NOUN
#> 101 say VERB
#> 102 they PRON
#> 103 believe VERB
#> 104 they PRON
#> 105 find VERB
#> 106 the DET
#> 107 shooter NOUN
#> 108 's PART
#> 109 backpack NOUN
#> 110 in ADP
#> 111 Central_Park ENTITY LOC
#> 112 on ADP
#> 113 December_6_,_2024 ENTITY DATE
#> 114 . PUNCT
#> 115 [ X
#> 116 the DET
#> 117 New_York_City ENTITY GPE
#> 118 Police PROPN
#> 119 Department PROPN
#> 120 offer VERB
#> 121 a DET
#> 122 reward NOUN
#> 123 up_to_$_10,000 ENTITY MONEY
#> 124 for ADP
#> 125 information NOUN
#> 126 about ADP
#> 127 the DET
#> 128 shooter NOUN
#> 129 on ADP
#> 130 December_4_,_2024 ENTITY DATE
#> 131 . PUNCT
#> 132 [ X
#> 133 the DET
#> 134 shooter NOUN
#> 135 be AUX
#> 136 describe VERB
#> 137 by ADP
#> 138 police NOUN
#> 139 as ADP
#> 140 a DET
#> 141 white ADJ
#> 142 man NOUN
#> 143 , PUNCT
#> 144 approximately_6 ENTITY CARDINAL
#> 145 ft NOUN
#> 146 1 NUM
#> 147 in ADP
#> 148 ( PUNCT
#> 149 185_cm ENTITY QUANTITY
#> 150 ) PUNCT
#> 151 tall ADJ
#> 152 , PUNCT
#> 153 wear VERB
#> 154 a DET
#> 155 light ADJ
#> 156 brown ADJ
#> 157 or CCONJ
#> 158 cream NOUN
#> 159 - PUNCT
#> 160 color VERB
#> 161 hooded ADJ
#> 162 jacket NOUN
#> 163 , PUNCT
#> 164 dark ADJ
#> 165 pant NOUN
#> 166 , PUNCT
#> 167 and CCONJ
#> 168 black ADJ
#> 169 sneaker NOUN
#> 170 with ADP
#> 171 white ADJ
#> 172 sol NOUN
#> 173 . PUNCT
#> 174 31][39][57][58 ENTITY CARDINAL
#> 175 ] PUNCT
#> 176 Police NOUN
#> 177 say VERB
#> 178 the DET
#> 179 suspect NOUN
#> 180 appear VERB
#> 181 to PART
#> 182 be AUX
#> 183 proficient ADJ
#> 184 in ADP
#> 185 the DET
#> 186 use NOUN
#> 187 of ADP
#> 188 firearms[30 NOUN
#> 189 ] PUNCT
#> 190 and CCONJ
#> 191 be AUX
#> 192 describe VERB
#> 193 as ADP
#> 194 be AUX
#> 195 " PUNCT
#> 196 extremely ADV
#> 197 camera NOUN
#> 198 savvy NOUN
#> 199 . PUNCT
#> 200 " PUNCT
#> 201 [ X
#> 202 69 ENTITY CARDINAL
#> 203 ] PUNCT
#> 204 Mangione ENTITY ORG
#> 205 's PART
#> 206 mother NOUN
#> 207 contact VERB
#> 208 the_San_Francisco_Police_Department ENTITY ORG
#> 209 , PUNCT
#> 210 as SCONJ
#> 211 she PRON
#> 212 believe VERB
#> 213 that SCONJ
#> 214 Mangione ENTITY ORG
#> 215 live VERB
#> 216 in ADP
#> 217 San_Francisco ENTITY GPE
#> 218 and CCONJ
#> 219 have VERB
#> 220 a DET
#> 221 job NOUN
#> 222 in ADP
#> 223 the DET
#> 224 area NOUN
#> 225 . PUNCT
#> 226 [ X
#> 227 local ADJ
#> 228 police NOUN
#> 229 in ADP
#> 230 Altoona ENTITY GPE
#> 231 , PUNCT
#> 232 Pennsylvania ENTITY GPE
#> 233 , PUNCT
#> 234 arrest VERB
#> 235 Mangione ENTITY ORG
#> 236 on ADP
#> 237 December_9_,_2024 ENTITY DATE
#> 238 , PUNCT
#> 239 at ADP
#> 240 a DET
#> 241 McDonald ENTITY ORG
#> 242 's PART
#> 243 restaurant NOUN
#> 244 in ADP
#> 245 the DET
#> 246 city NOUN
#> 247 . PUNCT
#> 248 an DET
#> 249 employee NOUN
#> 250 there ADV
#> 251 call VERB
#> 252 the DET
#> 253 police NOUN
#> 254 to PART
#> 255 say VERB
#> 256 that SCONJ
#> 257 a DET
#> 258 customer NOUN
#> 259 recognize VERB
#> 260 the DET
#> 261 suspect NOUN
#> 262 from ADP
#> 263 image NOUN
#> 264 release VERB
#> 265 by ADP
#> 266 the DET
#> 267 NYPD ENTITY ORG
#> 268 . PUNCT
#> 269 [ X
#> 270 63 ENTITY CARDINAL
#> 271 ] PUNCT
#> 272 in ADP
#> 273 his PRON
#> 274 bag NOUN
#> 275 they PRON
#> 276 find VERB
#> 277 a DET
#> 278 3d NOUN
#> 279 - PUNCT
#> 280 print VERB
#> 281 gun NOUN
#> 282 and CCONJ
#> 283 a DET
#> 284 3d NOUN
#> 285 - PUNCT
#> 286 print VERB
#> 287 suppressor NOUN
#> 288 , PUNCT
#> 289 which PRON
#> 290 the DET
#> 291 police NOUN
#> 292 claim NOUN
#> 293 be AUX
#> 294 consistent ADJ
#> 295 with ADP
#> 296 the DET
#> 297 weapon NOUN
#> 298 use VERB
#> 299 in ADP
#> 300 the DET
#> 301 shooting NOUN
#> 302 , PUNCT
#> 303 and CCONJ
#> 304 a DET
#> 305 falsify VERB
#> 306 New_Jersey ENTITY GPE
#> 307 driver NOUN
#> 308 's PART
#> 309 license NOUN
#> 310 with ADP
#> 311 the DET
#> 312 same ADJ
#> 313 name NOUN
#> 314 as ADP
#> 315 the DET
#> 316 one NOUN
#> 317 use VERB
#> 318 by ADP
#> 319 the DET
#> 320 alleged ADJ
#> 321 shooter NOUN
#> 322 to PART
#> 323 check VERB
#> 324 into ADP
#> 325 the DET
#> 326 Manhattan ENTITY GPE
#> 327 hostel NOUN
#> 328 . PUNCT
#> 329 [ X
#> 330 8][73][3][74 ENTITY CARDINAL
#> 331 ] PUNCT
#> 332 SPACE
#> 333 the DET
#> 334 police NOUN
#> 335 also ADV
#> 336 say VERB
#> 337 that SCONJ
#> 338 when SCONJ
#> 339 they PRON
#> 340 arrest VERB
#> 341 Mangione PROPN
#> 342 , PUNCT
#> 343 they PRON
#> 344 find VERB
#> 345 a DET
#> 346 three_-_page,[74_] ENTITY CARDINAL
#> 347 262 ENTITY CARDINAL
#> 348 - PUNCT
#> 349 word NOUN
#> 350 handwritten ADJ
#> 351 document NOUN
#> 352 about ADP
#> 353 the DET
#> 354 american ENTITY NORP
#> 355 healthcare NOUN
#> 356 system NOUN
#> 357 , PUNCT
#> 358 which PRON
#> 359 they PRON
#> 360 characterize VERB
#> 361 as ADP
#> 362 a DET
#> 363 manifesto NOUN
#> 364 . PUNCT
#> 365 [ X
#> 366 85 ENTITY CARDINAL
#> 367 ] PUNCT
#> 368 Police NOUN
#> 369 believe VERB
#> 370 the DET
#> 371 motive NOUN
#> 372 be AUX
#> 373 relate VERB
#> 374 to ADP
#> 375 an DET
#> 376 injury NOUN
#> 377 that PRON
#> 378 Mangione ENTITY ORG
#> 379 have AUX
#> 380 suffer VERB
#> 381 that PRON
#> 382 cause VERB
#> 383 he PRON
#> 384 to PART
#> 385 visit VERB
#> 386 the DET
#> 387 emergency NOUN
#> 388 room NOUN
#> 389 in ADP
#> 390 July_2023 ENTITY DATE
#> 391 . PUNCT
#> 392 New_York ENTITY GPE
#> 393 Police PROPN
#> 394 Chief PROPN
#> 395 of ADP
#> 396 Detectives PROPN
#> 397 Joseph_Kenny ENTITY PERSON
#> 398 believe VERB
#> 399 Mangione PROPN
#> 400 may AUX
#> 401 have AUX
#> 402 target VERB
#> 403 they PRON
#> 404 because SCONJ
#> 405 of ADP
#> 406 the DET
#> 407 company NOUN
#> 408 's PART
#> 409 size NOUN
#> 410 . PUNCT
#> 411 [ X
#> 412 Police NOUN
#> 413 believe VERB
#> 414 that SCONJ
#> 415 Mangione ENTITY ORG
#> 416 be AUX
#> 417 inspire VERB
#> 418 by ADP
#> 419 Ted_Kaczynski_'s ENTITY PERSON
#> 420 Industrial_Society_and_its_Future ENTITY ORG
#> 421 . PUNCT
#> 422 [ X